using System;
using Server;
using Server.Accounting;
using System.IO;
using Server.Items;
using Server.Regions;

namespace Server.Misc
{
	public class AccountPrompt
	{
		// This script prompts the console for a username and password when 0 accounts have been loaded
		public static void Initialize()
		{
            //**********// Begin the reading of player city regions -- CITY LOADs
            Console.Write("World: Loading player cities...");
            
            foreach (Item i in World.Items.Values)
            {
                if (i is CityManagementStone)
                {
                    CityManagementStone s = (CityManagementStone)i;
                    int offset = 1;
                    switch (s.Level)
                    {
                        case 1:
                            offset = PlayerGovernmentSystem.L1CLOffset; break;
                        case 2:
                            offset = PlayerGovernmentSystem.L2CLOffset; break;
                        case 3:
                            offset = PlayerGovernmentSystem.L3CLOffset; break;
                        case 4:
                            offset = PlayerGovernmentSystem.L4CLOffset; break;
                        case 5:
                            offset = PlayerGovernmentSystem.L5CLOffset; break;
                        case 6:
                            offset = PlayerGovernmentSystem.L6CLOffset; break;
                    }
                    Point2D center = new Point2D(s.X, s.Y);
                    Point2D start = new Point2D(center.X - offset, center.Y - offset);
                    Point2D end = new Point2D(center.X + offset, center.Y + offset);
                    Rectangle2D box = new Rectangle2D(start, end);

                    PlayerCityRegion reg = new PlayerCityRegion(s, s.Map, s.CityName, box);
                    reg.Register();
                    s.PCRegion = reg; // set region to stone

                    //what else do we load about the regions.. guarded and...
                    reg.Disabled = false;
                    if (s.IsGuarded) reg.Disabled = true;
                }
            }
            Console.WriteLine("...done");
            //done ************

			if ( Accounts.Count == 0 && !Core.Service )
			{
				Console.WriteLine( "This server has no accounts." );
				Console.Write( "Do you want to create an administrator account now? (y/n)" );

				if( Console.ReadKey( true ).Key == ConsoleKey.Y )
				{
					Console.WriteLine();

					Console.Write( "Username: " );
					string username = Console.ReadLine();

					Console.Write( "Password: " );
					string password = Console.ReadLine();

					Account a = new Account( username, password );
					a.AccessLevel = AccessLevel.Owner;

					Console.WriteLine( "Account created." );
				}
				else
				{
					Console.WriteLine();

					Console.WriteLine( "Account not created." );
				}
			}
		}
	}
}