using System;
using Server;
using Server.Items;
using Server.Gumps;
using Server.Mobiles;
using Server.Prompts;
using Server.Network;
using Server.Regions;

namespace Server.Gumps
{
	public class CityDisbandCityGump : Gump
	{
		private CityManagementStone m_Stone;

		public CityDisbandCityGump( CityManagementStone stone, Mobile from ) : base( 50, 50 )
		{
			m_Stone = stone;

			Closable=true;
			Disposable=true;
			Dragable=true;
			Resizable=false;
			AddPage(0);
			AddBackground(32, 27, 277, 65, 5120);
			AddLabel(41, 30, 1149, @"Are you sure you want to disband the city?");
			AddButton(186, 55, 247, 248, 2, GumpButtonType.Reply, 0);
			AddButton(85, 55, 242, 243, 1, GumpButtonType.Reply, 0);

		}

      	public override void OnResponse( NetState state, RelayInfo info ) 
      	{ 
			Mobile from = state.Mobile; 

			if ( from == null )
				return;

        	if ( info.ButtonID == 1 )
     	    {
		        from.SendGump( new CityManagementGump( m_Stone, from ) );
		    }

            if ( info.ButtonID == 2 )
         	{
				if ( m_Stone.Citizens != null )
				{
					foreach ( Mobile m in m_Stone.Citizens )
					{
						PlayerMobile pm = (PlayerMobile)m;
						m.SendMessage( 34, "The mayor of {0} has disbaned the city.", m_Stone.CityName );

						pm.City = null;
						pm.CityTitle = null;
						pm.ShowCityTitle = false;
                        m_Stone.PCRegion.Unregister();
					}
				}

				if ( m_Stone.isLockedDown != null )
				{
					foreach( Item ld in m_Stone.isLockedDown )
					{
						ld.Movable = true;
					}
				}

                foreach (Item i in m_Stone.toDelete)
                {
                    if (i != null)
                    {
                        if (i is WoodCityHallAddon)
                        {
                            from.AddToBackpack(new WoodCityHallDeed());
                        }
                        else if (i is StoneCityHallAddon)
                        {
                            from.AddToBackpack(new StoneCityHallDeed());
                        }
                        else if (i is SandstoneCityHallAddon)
                        {
                            from.AddToBackpack(new SandstoneCityHallDeed());
                        }
                        else if (i is NecroCityHallAddon)
                        {
                            from.AddToBackpack(new NecroCityHallDeed());
                        }
                        else if (i is MarbleCityHallAddon)
                        {
                            from.AddToBackpack(new MarbleCityHallDeed());
                        }
                        else if (i is AsianCityHallAddon)
                        {
                            from.AddToBackpack(new AsianCityHallDeed());
                        }
                        else if (i is FieldstoneCityHallAddon)
                        {
                            from.AddToBackpack(new FieldStoneCityHallDeed());
                        }
                        else if (i is PlasterCityHallAddon)
                        {
                            from.AddToBackpack(new PlasterCityHallDeed());
                        }
                        i.Delete();
                    }
                }

                m_Stone.Delete();
				
				/*BaseHouse house = FindHouseAt( from );
				if ( house is WoodCityHallAddon )
					{
						from.AddToBackpack( new WoodCityHallDeed() );
					}
					else if ( item is StoneCityHallAddon )
					{
						from.AddToBackpack( new StoneCityHallDeed() );
					}
					else if ( item is PlasterCityHallAddon )
					{
						from.AddToBackpack( new PlasterCityHallDeed() );
					}
					else if ( item is FieldstoneCityHallAddon )
					{
						from.AddToBackpack( new FieldstoneCityHallDeed() );
					}
					else if ( item is SandstoneCityHallAddon )
					{
						from.AddToBackpack( new SandstoneCityHallDeed() );
					}
					else if ( item is NecroCityHallAddon )
					{
						from.AddToBackpack( new NecroCityHallDeed() );
					}
					else if ( item is MarbleCityHallAddon )
					{
						from.AddToBackpack( new MarbleCityHallDeed() );
					}
					else if ( item is AsianCityHallAddon )
					{
						from.AddToBackpack( new AsianCityHallDeed() );
					}*/

			}
		}
	}
}