using System;
using Server;
using Server.Items;
using Server.Gumps;
using Server.Mobiles;
using Server.Prompts;
using Server.Regions;
using System.IO;

namespace Server.Prompts
{
	public class CityNamePrompt : Prompt
	{
		private CityManagementStone m_Stone;
		private Mobile m_From;
        private Rectangle2D m_Box;

		public CityNamePrompt( CityManagementStone stone, Mobile from, Rectangle2D box )
		{
			m_Stone = stone;
			m_From = from;
            m_Box = box;
		}

		public override void OnCancel( Mobile from )
		{
			m_From.CloseGump( typeof( CityManagementGump ) );
			m_From.SendGump( new CityManagementGump( m_Stone, m_From ) );
		}

		public override void OnResponse( Mobile from, string text )
		{
            text = text.Trim();

            if (text.Length > 40)
                text = text.Substring(0, 40);

            if (text.Length > 0)
            {
                if (PlayerGovernmentSystem.CheckCityName(text))
                {
                    m_From.SendMessage("That name conflicts with another cities name.");
                }
                else
                {
                    m_Stone.CityName = text;

                    if (m_Stone.Citizens != null)
                    {
                        foreach (Mobile m in m_Stone.Citizens)
                        {
                            m.SendMessage(53, "Your city's name has been set to {0}.", text);
                            m_Stone.CityName = text;

                            PlayerMobile pm = (PlayerMobile)m;

                            if (pm.ShowCityTitle == true) // Updates Title
                                pm.ShowCityTitle = true;

                            // Setup Region
                            if (m_Stone.PCRegion != null)
                            { m_Stone.PCRegion.Unregister(); }
                            
                            PlayerCityRegion reg = new PlayerCityRegion(m_Stone, from.Map, m_Stone.CityName, m_Box);
                            reg.Register();
                            m_Stone.PCRegion = reg;
                        }
                    }
                }
                
                m_From.CloseGump(typeof(CityManagementGump));
                m_From.SendGump(new CityManagementGump(m_Stone, m_From));
            }
		}
	}
}